@@ -31,8 +31,6 @@ from plugins.helpers import log_calls
 from nbxmpp.simplexml import Node
 from nbxmpp import NS_CORRECT, NS_ADDRESS
 
-from . import ui
-from .ui import Ui
 from .xmpp import (
     NS_NOTIFY, NS_OMEMO, NS_EME, BundleInformationAnnouncement,
     BundleInformationQuery, DeviceListAnnouncement, DevicelistQuery,
@@ -75,6 +73,7 @@ except Exception as e:
 if not ERROR_MSG:
     try:
         from .omemo.state import OmemoState
+        from .ui import Ui, OMEMOConfigDialog
     except Exception as e:
         log.error(e)
         ERROR_MSG = 'Error: ' + str(e)
@@ -118,6 +117,7 @@ class OmemoPlugin(GajimPlugin):
         if ERROR_MSG:
             self.activatable = False
             self.available_text = ERROR_MSG
+            self.config_dialog = None
             return
         self.events_handlers = {
             'mam-message-received': (ged.PRECORE, self.mam_message_received),
@@ -139,7 +139,7 @@ class OmemoPlugin(GajimPlugin):
             self.events_handlers['muc-admin-received'] =\
                 (ged.PRECORE, self.room_memberlist_received)
 
-        self.config_dialog = ui.OMEMOConfigDialog(self)
+        self.config_dialog = OMEMOConfigDialog(self)
         self.gui_extension_points = {'chat_control': (self.connect_ui,
                                                       self.disconnect_ui),
                                      'groupchat_control': (self.connect_ui,
@@ -547,6 +547,10 @@ class OmemoPlugin(GajimPlugin):
         if account in self.disabled_accounts:
             return
         try:
+            # If we send a correction msg, the stanza is saved
+            # in correction_msg
+            if event.correction_msg:
+                event.msg_iq = event.correction_msg
             if not event.msg_iq.getTag('body'):
                 return
             state = self.get_omemo_state(account)
@@ -588,7 +592,12 @@ class OmemoPlugin(GajimPlugin):
             # Store Hint for MAM
             store = Node('store', attrs={'xmlns': NS_HINTS})
             event.msg_iq.addChild(node=store)
-            self.print_msg_to_log(event.msg_iq)
+            if event.correction_msg:
+                event.correction_msg = event.msg_iq
+                event.msg_iq = None
+                self.print_msg_to_log(event.correction_msg)
+            else:
+                self.print_msg_to_log(event.msg_iq)
         except Exception as e:
             log.debug(e)
             return True
@@ -723,9 +732,13 @@ class OmemoPlugin(GajimPlugin):
 
         devices_list = list(set(unpack_device_list_update(event.stanza,
                                                           event.conn.name)))
-        if len(devices_list) == 0:
-            return False
         contact_jid = gajim.get_jid_without_resource(event.fjid)
+        if len(devices_list) == 0:
+            log.error(account +
+                      ' => Received empty or invalid Devicelist from: ' +
+                      contact_jid)
+            return False
+
         state = self.get_omemo_state(account)
         my_jid = gajim.get_jid_from_account(account)
 
@@ -1059,15 +1072,16 @@ class OmemoPlugin(GajimPlugin):
         state = self.get_omemo_state(account)
 
         if successful(stanza):
-            log.info(account + ' => Devicelistquery was successful')
             devices_list = list(set(unpack_device_list_update(stanza, account)))
             if len(devices_list) == 0:
+                log.error(account + ' => Devicelistquery was NOT successful')
+                self.publish_own_devices_list(account)
                 return False
             contact_jid = stanza.getAttr('from')
             if contact_jid == my_jid:
                 state.set_own_devices(devices_list)
                 state.store.sessionStore.setActiveState(devices_list, my_jid)
-
+                log.info(account + ' => Devicelistquery was successful')
                 # remove contact from list, so on send button pressed
                 # we query for bundle and build a session
                 if contact_jid in self.query_for_bundles:
